function [co] = HRenyi_weightedkNN_initialization(mult)
%Initialization of the weighted kNN based Renyi entropy (H) estimator.
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'H<name>_initialization' to ease embedding new entropy estimation methods.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'Renyi_weightedkNN';
    co.mult = mult;
    
%other fields:
    co.alpha = 0.95; %The Renyi entropy (H_{R,alpha}) equals to the Shannon differential entropy (H) in limit: H_{R,alpha} -> Shannon=H, as alpha -> 1.
    %Possibilities for 'co.kNNmethod' (see 'kNN_squared_distances.m'): 
        %I: 'knnFP1': fast pairwise distance computation and C++ partial sort; parameter: co.k.
        %II: 'knnFP2': fast pairwise distance computation; parameter: co.k. 												 		
        %III: 'knnsearch' (Matlab Statistics Toolbox): parameters: co.k, co.NSmethod ('kdtree' or 'exhaustive').        
        %IV: 'ANN' (approximate nearest neighbor); parameters: co.k, co.epsi. 
		%Note. co.k (the number of neighbors) depends on the number of samples used for estimation, it is set in 'HRenyi_weightedkNN_estimation.m'.
		%I:
            co.kNNmethod = 'knnFP1';
		%II:
            %co.kNNmethod = 'knnFP2';
        %III:
            %co.kNNmethod = 'knnsearch';
            %co.NSmethod = 'kdtree';
        %IV:
            %co.kNNmethod = 'ANN';
            %co.epsi = 0; %=0: exact kNN; >0: approximate kNN, the true (not squared) distances can not exceed the real distance more than a factor of (1+epsi).

%initialize the ann wrapper in Octave, if needed:
    initialize_Octave_ann_wrapper_if_needed(co.kNNmethod);
            
