function [H] = HShannon_Voronoi_estimation(Y,co)
%Estimates the Shannon entropy (H) of Y using Voronoi regions.
%
%We use the naming convention 'H<name>_estimation' to ease embedding new entropy estimation methods.
%
%INPUT:
%   Y: Y(:,t) is the t^th sample.
%  co: entropy estimator object.
%
%REFERENCE: 
%   Erik Miller. A new class of entropy estimators for multi-dimensional densities. International Conference on Acoustics, Speech, and Signal Processing (ICASSP), pp. 297-300, 2003. 
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%co.mult:OK.

[d,num_of_samples] = size(Y);
%verification:
    if d==1
        error('The dimension of the samples must be >=2 for this estimator.');
    end

[V,C] = voronoin(Y.');
num_of_unbounded_regions = 0;
H = 0;
for k = 1 : length(C)
    if isempty(find(C{k}==1)) %bounded region
        %[c,volume] = convhulln(V(C{k},:)); 
        [c,volume] = convhulln(V(C{k},:),{'Qx'}); 
        H = H + log(num_of_samples * volume);
    else %unbounded region
	num_of_unbounded_regions = num_of_unbounded_regions + 1;
    end
end
H = H / (num_of_samples-num_of_unbounded_regions);  

