function [I] = IQMI_CS_KDE_direct_estimation(Y,ds,co)
%Estimates the Cauchy-Schwartz quadratic mutual information (I) directly based on Gaussian KDE (kernel density estimation). 
%
%We use the naming convention 'I<name>_estimation' to ease embedding new mutual information estimation methods.
%
%INPUT:
%   Y: Y(:,t) is the t^th sample.
%  ds: subspace dimensions.
%  co: mutual information estimator object.
%
%REFERENCE: 
%   Sohan Seth and Jose C. Principe. On speeding up computation in information theoretic learning. International Joint Conference on Neural Networks (IJCNN), pages 2883-2887, 2009.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%co.mult:OK.

%verification:
    if sum(ds) ~= size(Y,1);
        error('The subspace dimensions are not compatible with Y.');
    end
    if ~one_dimensional_problem(ds) || length(ds)~=2
        error('There must be 2 pieces of one-dimensional subspaces (coordinates) for this estimator.');
    end

I = qmi_cs_2(Y(1:ds(1),:).',Y(ds(1)+1:ds(1)+ds(2),:).',co.sigma);



