function [co] = ACIM_initialization(mult)
%Initialization of the correntropy induced metric estimator, defined according to the relation CIM(y^1,y^_2) = [k(0,0)-correntropy(y^1,y^2)]^{1/2}, where k is the applied (Gaussian) kernel.
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'A<name>_initialization' to ease embedding new association measure estimator methods.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'CIM';
    co.mult = mult;
    
%other fields:
    co.member_name = 'CorrEntr_KDE_direct'; %you can change it to any (Gaussian kernel based) correntropy estimator
    co.member_co = A_initialization(co.member_name,mult);
