function [co] = HShannon_DKL_N_initialization(mult)
%Initialization of the "meta" Shannon entropy estimator defined according to the relation H(Y) = H(G) - D(Y,G), where G is Gaussian [N(E(Y),cov(Y)] and D is the Kullback-Leibler divergence.
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'H<name>_initialization' to ease embedding new entropy estimation methods.
%   3)This is a meta method: the Kullback-Leibler divergence estimator can be arbitrary.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'Shannon_DKL_N';
    co.mult = mult;
    
%other fields:
    co.member_name = 'KL_kNN_k'; %you can change it to any Kullback-Leibler divergence estimator
    co.member_co = D_initialization(co.member_name,mult);
