function [co] = Hcomplex_initialization(mult)
%Initialization of the "meta" complex entropy estimator. The estimator is constructed from a real-valued (vector) entropy estimator.
%
%Note:
%   1)The estimator is treated as a cost object (co). 
%   2)We use the naming convention 'H<name>_initialization' to ease embedding new entropy estimation methods.
%   3)This is a meta method: the real-valued (vector) entropy estimator can be arbitrary.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'complex';
    co.mult = mult;
    
%other fields:
    co.member_name = 'Renyi_kNN_k'; %you can change it to any real entropy estimator.
    co.member_co = H_initialization(co.member_name,mult);
    
