function [I] = IApprCorrEntr_estimation(Y,ds,co)
%Estimates the approximate correntropy independence measure (I) based on centered correntropy, using the relation: I(y^1,y^2) = max(|CCorrEntr(y^1,y^2)|,|CCorrEntr(-y^1,y^2)|), where CCorrEntr denotes centered correntropy.
%
%Note:
%   1)We use the naming convention 'I<name>_estimation' to ease embedding new mutual information estimation methods.
%   2)This a meta method: the centered correntropy estimator can be arbitrary.
%
%INPUT:
%   Y: Y(:,t) is the t^th sample.
%  ds: subspace dimensions.
%  co: mutual information estimator object.
%
%REFERENCE:
%   Murali Rao, Sohan Seth, Jianwu Xu, Yunmei Chen, Hemant Tagare, and Jose C. Principe. A test of independence based on a generalized correlation function. Signal Processing, 91:15-27, 2011.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%co.mult:OK.

%verification:
    if sum(ds) ~= size(Y,1);
        error('The subspace dimensions are not compatible with Y.');
    end
    if ~one_dimensional_problem(ds) || length(ds)~=2 
        error('There must be 2 pieces of one-dimensional subspaces (coordinates) for this estimator.');
    end

A1 = A_estimation(Y,ds,co.member_co);%[Y1;Y2]
A2 = A_estimation([-Y(1,:);Y(2,:)],ds,co.member_co);%[-Y1;Y2]
I = max(abs(A1),abs(A2));

