function [co] = IMMD_DMMD_initialization(mult)
%Initialization of the "meta" mutual information estimator based on MMD (maximum mean discrepancy).
%Mutual information is estimated using the relation: I(Y_1,...,Y_d) = MMD(P_Z,P_U), where (i) Z =[F_1(Y_1);...;F_d(Y_d)] is the
%copula transformation of Y; F_i is the cdf of Y_i, (ii) P_U is the uniform distribution on [0,1]^d, (iii) dim(Y_1) = ... = dim(Y_d) = 1.
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'I<name>_initialization' to ease embedding new mutual information estimation methods.
%   3)This is a meta method: the MMD estimator can be arbitrary. 
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'MMD_DMMD';
    co.mult = mult;
	
%other fields:    
    co.member_name = 'MMD_online'; %you can change it to any MMD estimator
    co.member_co = D_initialization(co.member_name,mult);
