function [co] = IRenyi_DRenyi_initialization(mult)
%Initialization of the "meta" Renyi mutual information estimator based on Renyi divergence.
%Mutual information is estimated using the relation: I(y^1,...,y^M) = D(f_y,\prod_{m=1}^M f_{y^m}).
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'I<name>_initialization' to ease embedding new mutual information estimation methods.
%   3)This is a meta method: the Renyi divergence estimator can be arbitrary.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'Renyi_DRenyi';
    co.mult = mult;
    co.alpha = 0.95;
	
%other fields:    
    co.member_name = 'Renyi_kNN_k'; %you can change it to any Renyi divergence estimator
    co.member_co = D_initialization(co.member_name,mult);

    co.member_co.alpha = co.alpha; %automatism for setting the parameters (co.alpha) of member_co (co_2) in a <=2 deep meta construction (co_1 -> co_2); otherwise, please set the parameters (co.alpha) in the member_co-s.
