function [co] = IdCov_IHSIC_initialization(mult)
%Initialization of the distance covariance estimator. The estimation is carried out based on the formula: [I(y^1,y^2;rho_1,rho_2)]^2 = 4 [HSIC(y^1,y^2;k)]^2, where HSIC stands for the Hilbert-Schmidt independence criterion, y=[y^1;y^2] has density f, y^i-s have density f_i-s, and k=k_1 x k_2, where k_i-s generates rho_i-s, semimetrics of negative type used in distance covariance.
%
%Note:
%   1)The estimator is treated as a cost object (co).
%   2)We use the naming convention 'I<name>_initialization' to ease embedding new mutual information estimation methods.
%   3)This is a meta method: the MMD estimator can be arbitrary. 
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'dCov_IHSIC';
    co.mult = mult;
	
%other fields:    
    co.member_name = 'HSIC'; %you can change it to any HSIC estimator
    co.member_co = I_initialization(co.member_name,mult);
