function [L] = compute_MST(W,method)
%Computes the minimum spanning tree on the weight matrix 'W' with the
%specified 'method'. 
%
%INPUT:
%   W: similarity matrix, square.
%   method: MST method. Possibilities: 'MatlabBGL_Prim', 'MatlabBGL_Kruskal', 'pmtk3_Prim', 'pmtk3_Kruskal'.
%OUTPUT:
%   L: total cost of the optimal tree.
%EXAMPLE:
%   A = rand(5); A = A+A.';  L = compute_MST(A,'MatlabBGL_Prim'), L = compute_MST(A,'MatlabBGL_Kruskal'), L = compute_MST(A,'pmtk3_Prim'), L = compute_MST(A,'pmtk3_Kruskal'),

%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

switch method
    case 'MatlabBGL_Prim'
        [i,j,v] = prim_mst(sparse(W));
        L = sum(v);%total weight
    case 'MatlabBGL_Kruskal'
        [i,j,v] = kruskal_mst(sparse(W));
        L = sum(v);%total weight
    case 'pmtk3_Prim'
        [temp,L] = minSpanTreePrim(W);
    case 'pmtk3_Kruskal'
        [temp,L] = minSpanTreeKruskal(W);
    otherwise
         error('MST method=?');
end
