function [L] = compute_length_HRenyi_GSF(Y,co)
%Computes the length (L) associated to the 'Renyi_GSF' Renyi entropy estimator.
%
%INPUT:
%    Y: Y(:,t) is the t^th sample.
%   co: cost object.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

[d,num_of_samples] = size(Y);

%compute kNN graph (S={1,...,k}):
    [squared_distances,I] = kNN_squared_distances(Y,Y,co,1);%I:int32
    
%kNN relations -> weighted kNN graph (W):
    J = repmat(int32([1:num_of_samples]),co.k,1);%double->int32
    D = squared_distances(:).^(d*(1-co.alpha));
    W = spalloc(num_of_samples,num_of_samples,2*num_of_samples*co.k);
    W(I+(J-1)*num_of_samples) = D;
    W(J+(I-1)*num_of_samples) = D;
    %The result obtained by co.kNNmethod = 'knnFP1' (squared distances) may contain an '1e-15' rounding error which
    %can cause W to be not _perfectly_ sym. This '1e-15' difference must be/is corrected below:
        if strcmp(co.kNNmethod,'knnFP1')
            W = W + W.';
        end

%W->L (using MatlabBGL); minimal spanning forest, and its weight (L): 
    L = compute_MST(W,co.GSFmethod);
