function [Dtemp2] = estimate_Dtemp2(X,Y,co)
%Estimates Dtemp2 = \int p^a(x)q^b(x)dx; the Hellinger distance and the Bhattacharyya distance are simple functions of this quantity.
%
%INPUT:
%   X: X(:,t) is the t^th sample from the first distribution.
%   Y: Y(:,t) is the t^th sample from the second distribution.
%  co: cost object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%initialization:
    [d,num_of_samplesY] = size(Y);
    [d,num_of_samplesX] = size(X);
    a = co.a;
    b = co.b;
    k = co.k;

squared_distancesXX = kNN_squared_distances(X,X,co,1);
squared_distancesYX = kNN_squared_distances(Y,X,co,0);
dist_k_XX = sqrt(squared_distancesXX(end,:));
dist_k_YX = sqrt(squared_distancesYX(end,:));

c = volume_of_the_unit_ball(d);
B = c^(-(a+b)) * gamma(k)^2 / (gamma(k-a)*gamma(k-b));
Dtemp2 = (num_of_samplesX-1)^(-a) * num_of_samplesY^(-b) * B * mean(dist_k_XX.^(-d*a).*dist_k_YX.^(-d*b));

